@@ -36,7 +36,10 @@ class DailyFileHandler(logging.FileHandler):
             self._day = day
             super(DailyFileHandler, self).close()
             self.baseFilename = self.filename_on_day(self._day)
-            self.mkdir(self.baseFilename)
+            try:
+                self.mkdir(self.baseFilename)
+            except OSError:
+                pass
             self.stream = open(self.baseFilename, "w")
         super(DailyFileHandler, self).emit(record)
 
